* **Getting Started**
  * [Overview](/)
  * [Installation](installation.md)
  * [Quick Start](quick-start.md)
  * [Core Concepts](concepts.md)

* **Block System**
  * [Overview](blocks/overview.md)
  * [LLM Blocks](blocks/llm-blocks.md)
  * [Transform Blocks](blocks/transform-blocks.md)
  * [Filtering Blocks](blocks/filtering-blocks.md)
  * [Custom Blocks](blocks/custom-blocks.md)

* **Flow System**
  * [Overview](flows/overview.md)
  * [YAML Configuration](flows/yaml-configuration.md)
  * [Flow Discovery](flows/discovery.md)
  * [Custom Flows](flows/custom-flows.md)

* **Advanced**
  * [API Reference](api-reference.md)
  * [Development](development.md)